{***********************************************************}
{    HotPDF PDF Component                                   }
{    Copyright(c)2007-2018, https://www.loslab.com          }
{***********************************************************}

program GraphicDraw;
{$APPTYPE CONSOLE}
{$I ..\HotPDF.inc}

uses
{$IFDEF XE2+} System.SysUtils, System.Classes, Vcl.Graphics,
{$ELSE} SysUtils, Classes, Graphics, {$ENDIF} HPDFDoc;

var
   HotPDF: THotPDF;
   DashArray: array of byte;
   OutlineRoot: THPDFDocOutlineObject;
   CurrnetOutline: THPDFDocOutlineObject;

   procedure DrawLine( Y : Integer );
   begin
       HotPDF.CurrentPage.MoveTo( 160, Y);
       HotPDF.CurrentPage.LineTo( 310, Y);
       HotPDF.CurrentPage.Stroke;
   end;

var
    i: Integer;

begin
    Randomize;
    HotPDF:= THotPDF.Create(nil);
    try
        HotPDF.AutoLaunch := true;
        HotPDF.NotEmbeddedFonts.Add('Arial');
        HotPDF.StandardFontEmulation := true;
        HotPDF.FileName := 'GraphicDraw.pdf';
        HotPDF.PageLayout := plOneColumn;           // One column viewer mode
        HotPDF.BeginDoc( true );                    // Create PDF file
        OutlineRoot := HotPDF.OutlineRoot;          // Get Outlines Root
        CurrnetOutline := OutlineRoot.AddChild( 'Lines' );          // Add Outline block linked to 0, 0 in current page
        CurrnetOutline.Opened := true;                              // Current outline is opened;

        //----------------------------  Examples of line width -----------------------------------------//
        CurrnetOutline.AddChild( 'Width examples', 175, 25 );           // Add Outline block linked to 190, 225 in current page
        HotPDF.CurrentPage.SetRGBStrokeColor( clRed );                   // Set red line color
        HotPDF.CurrentPage.SetFont('Arial', [fsBold, fsUnderline], 16);    // Show page header
        HotPDF.CurrentPage.TextOut( 175, 25, 0, 'Line width demo' );
        HotPDF.CurrentPage.SetFont('Arial', [], 10 );
        for I := 1 to 8 do
        begin
            HotPDF.CurrentPage.TextOut( 215, 32 + I * 25, 0, 'Width = ' + FloatToStr(I * 0.25));      // Print line width
            HotPDF.CurrentPage.SetLineWidth( I * 0.25 );                                              // Set line width
            HotPDF.CurrentPage.MoveTo( 60, 45 + I * 25 );
            HotPDF.CurrentPage.LineTo( 520, 45 + I * 25 );                                            // Draw line
            HotPDF.CurrentPage.Stroke;                                                                // Stroke line
        end;

        //-------------------------  Examples of line dash patterns  -----------------------------------------------//
        HotPDF.CurrentPage.SetFont('Arial', [fsBold, fsUnderline], 16);  // Show page header
        HotPDF.CurrentPage.TextOut( 170, 285, 0, 'Line dash patterns' );
        HotPDF.CurrentPage.SetFont('Arial', [], 12);  // Show next header
        HotPDF.CurrentPage.SetLineWidth( 2 );
        HotPDF.CurrentPage.SetRGBStrokeColor( clGreen );   // Set Green line color
        CurrnetOutline.AddChild( 'Dash patterns', 70, 325 );          // Add Outline block linked to 70, 325 in current page
        HotPDF.CurrentPage.TextOut( 70, 325, 0, '[ ] 0                                                                        No dash; solid, unbroken lines' );
        DrawLine( 330 );
        SetLength(DashArray, 1);
        DashArray[0] := 6;
        HotPDF.CurrentPage.SetDash( DashArray, 0 );                     // Set dash array [6] 0
        HotPDF.CurrentPage.TextOut( 70, 360, 0, '[6] 0                                                                       6 units on, 6 units off,');
        DrawLine( 365 );
        DashArray[0] := 9;
        DashArray[1] := 7;
        HotPDF.CurrentPage.SetDash( DashArray, 0 );                     // Set dash array [9 7] 0
        HotPDF.CurrentPage.TextOut( 70, 395, 0, '[9 7] 0                                                                    9 on, 7 off, 9 on, 7 off,');
        DrawLine( 400 );
        SetLength(DashArray, 6);
        DashArray[0] := 10;
        DashArray[1] := 3;
        DashArray[2] := 2;
        DashArray[3] := 3;
        DashArray[4] := 2;
        DashArray[5] := 3;
        HotPDF.CurrentPage.SetDash( DashArray, 0 );  // Set dash array [10 3 2 3 2 3] 0
        HotPDF.CurrentPage.TextOut( 70, 430, 0, '[10 3 2 3 2 3] 0                                                     10 on, 3 off, 2 on, 3 off, 2 on, 3 off,');
        DrawLine( 435 );
        HotPDF.CurrentPage.NoDash;  // Set default dash style

        //------------------------------------  Examples of curves -----------------------------------------//
        CurrnetOutline.AddChild( 'Curves', 165, 490 );                 // Add Outline block linked to 210, 500 in current page
        HotPDF.CurrentPage.SetRGBStrokeColor( clRed );                    // Set red line color
        HotPDF.CurrentPage.SetFont('Arial', [fsBold, fsUnderline], 16);  // Show page header
        HotPDF.CurrentPage.TextOut( 165, 490, 0, 'Examples of curves' );
        HotPDF.CurrentPage.MoveTo( 80, 800 );
        HotPDF.CurrentPage.CurveToC( 50, 500, 150, 570, 270, 700 );      // Draw curve type C
        HotPDF.CurrentPage.Stroke;
        HotPDF.CurrentPage.MoveTo( 320, 800 );
        HotPDF.CurrentPage.CurveToY( 350, 620, 550, 670 );               // Draw curve type Y
        HotPDF.CurrentPage.Stroke;
        HotPDF.CurrentPage.SetRGBStrokeColor( clBlack );                 // Set black line color
        SetLength(DashArray, 1);                                       // Set braked line type
        DashArray [ 0 ] := 8;
        HotPDF.CurrentPage.SetDash( DashArray, 0 );
        HotPDF.CurrentPage.SetLineWidth( 0.5 );
        HotPDF.CurrentPage.MoveTo( 350, 620 );
        HotPDF.CurrentPage.LineTo( 320, 800 );                            // Draw dotted line
        HotPDF.CurrentPage.Stroke;
        HotPDF.CurrentPage.MoveTo( 80, 800 );
        HotPDF.CurrentPage.LineTo( 50, 550 );                            // Draw dotted line
        HotPDF.CurrentPage.Stroke;
        HotPDF.CurrentPage.MoveTo( 150, 570 );
        HotPDF.CurrentPage.LineTo( 270, 700 );                            // Draw dotted line
        HotPDF.CurrentPage.Stroke;
        HotPDF.CurrentPage.SetFont('Times New Roman', [], 10);                // Set label font
        HotPDF.CurrentPage.TextOut( 85, 790,0, 'Current point ( 80, 800 )' );
        HotPDF.CurrentPage.TextOut( 50, 550,0, 'X1 ( 50, 500 )' );
        HotPDF.CurrentPage.TextOut( 150, 560,0, 'X2 ( 150, 570 )' );
        HotPDF.CurrentPage.TextOut( 200, 700,0, 'X3 ( 270, 700 )' );
        HotPDF.CurrentPage.TextOut( 325, 790,0, 'Current point ( 320, 800 )' );
        HotPDF.CurrentPage.TextOut( 350, 610,0, 'X1 ( 350, 620 )' );
        HotPDF.CurrentPage.TextOut( 490, 685,0, 'X3 ( 550, 670 )' );
        HotPDF.CurrentPage.NoDash;                                       // Set default dash type
        HotPDF.AddPage;
        CurrnetOutline := OutlineRoot.AddChild( 'Rectangles' );        // Add Outline block linked to 0, 0 in current page
        CurrnetOutline.Opened := true;                                 // Current outline is opened;
        //------------------------------------  Draw  rectangles -----------------------------------------//
        HotPDF.CurrentPage.SetFont('Arial', [fsBold, fsUnderline], 16);  // Set header font
        CurrnetOutline.AddChild( 'Rectangles', 180, 25 );              // Add Outline block linked to 180, 25 in current page
        HotPDF.CurrentPage.TextOut( 180, 25, 0, 'Draw rectangles' );
        for I := 0 to 5 do
        begin
            HotPDF.CurrentPage.SetRGBFillColor(random($FFFFFF));         // Set rectangle color
            HotPDF.CurrentPage.Rectangle( I * 80 + 50, 50, 95, 130);      // Draw round rectangle
            HotPDF.CurrentPage.ClosePathFillAndStroke;                   // Close, fill and stroke rectangle
            HotPDF.CurrentPage.SetRGBFillColor(random($FFFFFF));         // Set rectangle color
            HotPDF.CurrentPage.Rectangle( I * 80 + 50, 70, 75, 130);    // Draw round rectangle
            HotPDF.CurrentPage.ClosePathFillAndStroke;                   // Close, fill and stroke rectangle
        end;
        HotPDF.CurrentPage.SetRGBFillColor( clBlack );                   //   Set default fill color
        //------------------------------------  Draw rotated rectangles -----------------------------------------//
        CurrnetOutline.AddChild( 'Rotated rectangles', 165, 225 );              // Add Outline block linked to 180, 225 in current page
        HotPDF.CurrentPage.TextOut( 165, 225, 0, 'Draw rotated rectangles' );
        for I := 1 to 8 do
        begin
            HotPDF.CurrentPage.SetRGBFillColor(random($FFFFFF));                     // Set rectangle color
            HotPDF.CurrentPage.RectangleRotate( I * 50 + 40, 420, 85, 120, I * 40);  // Draw rectangle
            HotPDF.CurrentPage.ClosePathFillAndStroke;                               // Close, fill and stroke rectangle
        end;
        HotPDF.CurrentPage.SetRGBFillColor( clBlack );                   //   Set default fill color
        //------------------------------------  Draw round rectangles -----------------------------------------//
        CurrnetOutline.AddChild( 'Round rectangles', 170, 590 );              // Add Outline block linked to 210, 600 in current page
        HotPDF.CurrentPage.TextOut( 170, 590, 0, 'Draw round rectangles' );
        for I := 0 to 5 do
        begin
            HotPDF.CurrentPage.SetRGBFillColor(random($FFFFFF));                         // Set rectangle color
            HotPDF.CurrentPage.RoundRect( I * 70 + 30, 630, I * 90+115, 770, 20, 20);    // Draw round rectangle
            HotPDF.CurrentPage.ClosePathFillAndStroke;                                   // Close, fill and stroke round rectangle
            HotPDF.CurrentPage.SetRGBFillColor(random($FFFFFF));                         // Set rectangle color
            HotPDF.CurrentPage.RoundRect( I * 70 + 30, 660, I * 90+125, 800, 20, 20);  // Draw round rectangle
            HotPDF.CurrentPage.ClosePathFillAndStroke;                                   // Close, fill and stroke round rectangle
        end;
        HotPDF.CurrentPage.SetRGBFillColor( clBlack );                      //   Set default rectangle color
        HotPDF.AddPage;
        CurrnetOutline := OutlineRoot.AddChild( 'Circles and ellipses' ); // Add Outline block linked to 0, 0 in current page
        CurrnetOutline.Opened := true;                                    // Current outline is opened;
        HotPDF.CurrentPage.SetFont('Arial', [fsBold, fsUnderline], 16);     // Set font
        //------------------------------------  Draw  circles -----------------------------------------//
        CurrnetOutline.AddChild( 'Circles', 250, 30 );              // Add Outline block linked to 250, 600 in current page
        HotPDF.CurrentPage.TextOut( 250, 30, 0, 'Circles' );
        for I := 1 to 8 do
        begin
            HotPDF.CurrentPage.SetRGBFillColor(random($FFFFFF));         // Set circle fill color
            HotPDF.CurrentPage.Circle( I * 50 + 50, 160, 80 / I );       // Draw circle
            HotPDF.CurrentPage.ClosePathFillAndStroke;                   // Close, fill and stroke circle
            HotPDF.CurrentPage.SetRGBFillColor(random($FFFFFF));         // Set circle fill color
            HotPDF.CurrentPage.Circle( I * 50 + 50, 290, I * 10 );       // Draw circle
            HotPDF.CurrentPage.ClosePathFillAndStroke;                   // Close, fill and stroke circle
        end;
        HotPDF.CurrentPage.SetRGBFillColor( clBlack );                   //   Set default rectangle color
        //------------------------------------  Draw  elipses -----------------------------------------//
        CurrnetOutline.AddChild( 'Ellipses', 250, 450 );              // Add Outline block linked to 270, 450 in current page
        HotPDF.CurrentPage.TextOut( 250, 450, 0, 'Ellipses' );
        for I := 1 to 8 do
        begin
            HotPDF.CurrentPage.SetRGBFillColor(random($FFFFFF));                           // Set ellipse fill color
            HotPDF.CurrentPage.Ellipse( I * 30, 500 + I * 3, 600 - I * 70, 270 - I * 6 );  // Draw ellipse
            HotPDF.CurrentPage.ClosePathFillAndStroke;                                     // Close, fill and stroke ellipse
        end;
        HotPDF.EndDoc;
    finally
        HotPDF.Free;
    end;
end.

