﻿{***********************************************************}
{    HotPDF PDF Component                                   }
{    Copyright(c)2007-2018, https://www.loslab.com          }
{***********************************************************}

program CharSet;
{$APPTYPE CONSOLE}
{$I ..\HotPDF.inc}

uses
{$IFDEF XE2+} WinApi.Windows, System.SysUtils, System.Classes, Vcl.Graphics,
{$ELSE} Windows, SysUtils, Classes, Graphics, {$ENDIF} HPDFDoc;

var
  HPDF: THotPDF;
  OutlineRoot: THPDFDocOutlineObject;

procedure ShowCharset ( FontCharset: TFontCharset; First, Last: Integer; Y1, Y2: Integer );
var
  i: Integer;
  CSName: AnsiString;
begin
  // https://docs.microsoft.com/en-us/previous-versions/cc194829(v=msdn.10)  
  case FontCharset of
    ANSI_CHARSET: CSName := 'ANSI_CHARSET';
    RUSSIAN_CHARSET: CSName := 'RUSSIAN_CHARSET';
  end;
    HPDF.CurrentPage.SetFont( 'Arial', [fsBold, fsItalic], 12);  // Set charset header font
    HPDF.CurrentPage.TextOut ( 50, Y1, 0, CSName + ' example: ');
    HPDF.CurrentPage.SetFont( 'Arial', [], 14, FontCharset );
    for I := First to Last do
    begin
      HPDF.CurrentPage.TextOut( 30 + (I mod 25) * 22, Y2 + (I div 25) * 17, 0 , AnsiChar(chr(I)) );
      //Show a sequence of characters in the computed position.
    end;
end;

begin
  HPDF:= THotPDF.Create(nil);
  try
    HPDF.AutoLaunch := true;

    HPDF.FileName := 'CharSet.pdf';
    HPDF.PageLayout := plOneColumn;       // One column viewer mode

    HPDF.BeginDoc( true );
    OutlineRoot := HPDF.OutlineRoot;      // Get Outlines Root

    //---------------------------  Charsets   --------------------------//

    HPDF.CurrentPage.SetFont('Arial', [fsBold, fsUnderline], 20);
    HPDF.CurrentPage.TextOut( 200, 160, 0, 'Charsets' );

    OutlineRoot.AddChild( 'Character Sets', 80, 100 );
    ShowCharset ( ANSI_CHARSET, 160, 250, 210, 110 );
    ShowCharset ( RUSSIAN_CHARSET, 160, 250, 320, 220 );

    //---------------------------  Show Turkish Characters   -----------//
    // search SetFont in HotPDF.chm and see TFontCharset
    // those FontCharset are defined by Windows & VCL
	{$IFDEF D2007+}
    HPDF.AddPage;
    HPDF.CurrentPage.SetFont('Microsoft Sans Serif', [], 16, 162);  // Charset Value 162: TURKISH_CHARSET
    HPDF.CurrentPage.TextOut( 20, 60, 0, 'TURKISH_CHARSET:' );
    HPDF.CurrentPage.UnicodeTextOut( 20, 100, 0, 'HotPDF Bileşeni, Delphi ve C ++ Builder için, PDF belgeleri oluşturma ' );
    HPDF.CurrentPage.UnicodeTextOut( 20, 120, 0, 've düzenleme olanağı sağlayan profesyonel bir VCL bileşenidir. ' );
    HPDF.CurrentPage.UnicodeTextOut( 20, 150, 0, 'HotPDF, PDF dosyalarını değiştirmek için herhangi bir DLL veya başka ' );
    HPDF.CurrentPage.UnicodeTextOut( 20, 170, 0, 'bir yazılım kullanmaz.' );
    OutlineRoot.AddChild( 'Turkish Characters', 20, 40 );
    {$ENDIF}
    HPDF.EndDoc;
  finally
    HPDF.Free;
  end;
end.